@@ -2,14 +2,14 @@
 #
 # SPDX-License-Identifier: BSD-3-Clause
 
-from PyQt5 import QtCore
+from PySide6 import QtCore
 from sdt import gui
 
 
 def test_url(qapp):
     c = gui.Component("""
-import QtQuick 2.15
-import SdtGui 0.2
+import QtQuick
+import SdtGui
 
 Item {
     property url testUrl: "file:///bla/blub/qua"
@@ -26,8 +26,8 @@ Item {
 
 def test_setQObjectParent(qapp):
     c = gui.Component("""
-import QtQuick 2.15
-import SdtGui 0.2
+import QtQuick
+import SdtGui
 
 Item {
     id: root
